Module arrow_data

Module arrow_data 

Structs

ArrowEngineData
ArrowEngineData holds an Arrow RecordBatch, implements EngineData so the kernel can extract from it.

Traits

EngineDataArrowExt
A trait to allow easy conversion from EngineData to an arrow [``RecordBatch]. Returns an error if called on an EngineDatathat is not anArrowEngineData`.

Functions

fix_nested_null_masks
Use this function to recursively compute properly unioned null masks for all nested columns of a record batch, making it safe to project out and consume nested columns.