pub struct ArrowEvaluationHandler;Trait Implementations
Sourceimpl Debug for ArrowEvaluationHandler
impl Debug for ArrowEvaluationHandler
Sourceimpl EvaluationHandler for ArrowEvaluationHandler
impl EvaluationHandler for ArrowEvaluationHandler
Sourcefn null_row(
&self,
output_schema: Arc<StructType>,
) -> Result<Box<dyn EngineData>, Error>
fn null_row( &self, output_schema: Arc<StructType>, ) -> Result<Box<dyn EngineData>, Error>
Create a single-row array with all-null leaf values. Note that if a nested struct is
included in the output_type, the entire struct will be NULL (instead of a not-null struct
with NULL fields).
Sourcefn new_expression_evaluator(
&self,
schema: Arc<StructType>,
expression: Arc<Expression>,
output_type: DataType,
) -> Result<Arc<dyn ExpressionEvaluator>, Error>
fn new_expression_evaluator( &self, schema: Arc<StructType>, expression: Arc<Expression>, output_type: DataType, ) -> Result<Arc<dyn ExpressionEvaluator>, Error>
Create an
ExpressionEvaluator that can evaluate the given Expression
on columnar batches with the given Schema to produce data of DataType. Read moreSourcefn new_predicate_evaluator(
&self,
schema: Arc<StructType>,
predicate: Arc<Predicate>,
) -> Result<Arc<dyn PredicateEvaluator>, Error>
fn new_predicate_evaluator( &self, schema: Arc<StructType>, predicate: Arc<Predicate>, ) -> Result<Arc<dyn PredicateEvaluator>, Error>
Create a
PredicateEvaluator that can evaluate the given Predicate on columnar
batches with the given Schema to produce a column of boolean results. Read moreAuto Trait Implementations
impl Freeze for ArrowEvaluationHandler
impl RefUnwindSafe for ArrowEvaluationHandler
impl Send for ArrowEvaluationHandler
impl Sync for ArrowEvaluationHandler
impl Unpin for ArrowEvaluationHandler
impl UnwindSafe for ArrowEvaluationHandler