Module executor

Module executor 

The default engine uses Async IO to read files, but the kernel APIs are all synchronous. Therefore, we need an executor to run the async IO on in the background.

A generic trait TaskExecutor can be implemented with your preferred async runtime. Behind the tokio feature flag, we provide a both a single-threaded and multi-threaded executor based on Tokio.

Modules

tokio

Traits

TaskExecutor
An executor that can be used to run async tasks. This is used by IO functions within the DefaultEngine.