DefaultEngine

Struct DefaultEngine 

pub struct DefaultEngine<E>
where E: TaskExecutor,
{ /* private fields */ }

Implementations

Source

impl DefaultEngine<TokioBackgroundExecutor>

pub fn new( object_store: Arc<dyn ObjectStore>, ) -> DefaultEngine<TokioBackgroundExecutor>

Create a new DefaultEngine instance with the default executor.

Uses TokioBackgroundExecutor as the default executor. For custom executors, use DefaultEngine::new_with_executor.

Parameters
  • object_store: The object store to use.
pub fn set_metrics_reporter(&mut self, reporter: Arc<dyn MetricsReporter>)

Set a metrics reporter for the engine to collect events and metrics during operations.

Parameters
  • reporter: An implementation of the MetricsReporter trait which will be used to report metrics.
Source

impl<E> DefaultEngine<E>
where E: TaskExecutor,

pub fn new_with_executor( object_store: Arc<dyn ObjectStore>, task_executor: Arc<E>, ) -> DefaultEngine<E>

Create a new DefaultEngine instance with a custom executor.

Most users should use DefaultEngine::new instead. This method is only needed for specialized testing scenarios (e.g., multi-threaded executors).

Parameters
  • object_store: The object store to use.
  • task_executor: Used to spawn async IO tasks. See executor::TaskExecutor.
pub fn get_object_store_for_url( &self, _url: &Url, ) -> Option<Arc<dyn ObjectStore>>

pub async fn write_parquet( &self, data: &ArrowEngineData, write_context: &WriteContext, partition_values: HashMap<String, String>, ) -> Result<Box<dyn EngineData>, Error>