CommitConflictError

Enum CommitConflictError 

pub enum CommitConflictError {
    ConcurrentAppend,
    ConcurrentDeleteRead,
    ConcurrentDeleteDelete,
    MetadataChanged,
    ConcurrentTransaction,
    ProtocolChanged(String),
    UnsupportedWriterVersion(i32),
    UnsupportedReaderVersion(i32),
    CorruptedState {
        source: Box<dyn Error + Send + Sync + 'static>,
    },
    Predicate {
        source: Box<dyn Error + Send + Sync + 'static>,
    },
    NoMetadata,
}
Exceptions raised during commit conflict resolution

Variants



ConcurrentAppend

This exception occurs when a concurrent operation adds files in the same partition (or anywhere in an un-partitioned table) that your operation reads. The file additions can be caused by INSERT, DELETE, UPDATE, or MERGE operations.



ConcurrentDeleteRead

This exception occurs when a concurrent operation deleted a file that your operation read. Common causes are a DELETE, UPDATE, or MERGE operation that rewrites files.



ConcurrentDeleteDelete

This exception occurs when a concurrent operation deleted a file that your operation also deletes. This could be caused by two concurrent compaction operations rewriting the same files.



MetadataChanged

This exception occurs when a concurrent transaction updates the metadata of a Delta table. Common causes are ALTER TABLE operations or writes to your Delta table that update the schema of the table.



ConcurrentTransaction

If a streaming query using the same checkpoint location is started multiple times concurrently and tries to write to the Delta table at the same time. You should never have two streaming queries use the same checkpoint location and run at the same time.



ProtocolChanged(String)

This exception can occur in the following cases:

  • When your Delta table is upgraded to a new version. For future operations to succeed you may need to upgrade your Delta Lake version.
  • When multiple writers are creating or replacing a table at the same time.
  • When multiple writers are writing to an empty path at the same time.


UnsupportedWriterVersion(i32)

Error returned when the table requires an unsupported writer version



UnsupportedReaderVersion(i32)

Error returned when the table requires an unsupported writer version



CorruptedState

Error returned when the snapshot has missing or corrupted data

Fields

source: Box<dyn Error + Send + Sync + 'static>

Source error



Predicate

Error returned when evaluating predicate

Fields

source: Box<dyn Error + Send + Sync + 'static>

Source error



NoMetadata

Error returned when no metadata was found in the DeltaTable.