Module engine

Module engine 

Provides an engine implementation that implements the required traits. The engine can optionally be built into the kernel by setting the default-engine feature flag. See the related module for more information.

Modules

arrow_conversion
Conversions from kernel schema types to arrow schema types.
arrow_data
arrow_expression
Expression handling based on arrow-rs compute kernels.
default
The Default Engine
parquet_row_group_skipping
An implementation of parquet row group skipping using data skipping predicates over footer stats.

Functions

parse_json
Arrow lacks the functionality to json-parse a string column into a struct column, so we implement it here. This method is for json-parsing each string in a column of strings (add.stats to be specific) to produce a nested column of strongly typed values. We require that N rows in means N rows out.
to_json_bytes
serialize an arrow RecordBatch to a JSON string by appending to a buffer.