A trait to allow easy conversion from EngineData to an arrow [``RecordBatch]. Returns an error if called on an EngineDatathat is not anArrowEngineData`.
Use this function to recursively compute properly unioned null masks for all nested
columns of a record batch, making it safe to project out and consume nested columns.