pub struct ArrowEngineData { /* private fields */ }Expand description
ArrowEngineData holds an Arrow RecordBatch, implements EngineData so the kernel can extract from it.
WARNING: Row visitors require that all leaf columns of the record batch have correctly computed
NULL masks. The arrow parquet reader is known to produce incomplete NULL masks, for
example. When in doubt, call fix_nested_null_masks first.
Implementations
Sourceimpl ArrowEngineData
impl ArrowEngineData
Sourcepub fn new(data: RecordBatch) -> ArrowEngineData
pub fn new(data: RecordBatch) -> ArrowEngineData
Create a new ArrowEngineData from a RecordBatch
Sourcepub fn try_from_engine_data(
engine_data: Box<dyn EngineData>,
) -> Result<Box<ArrowEngineData>, Error>
pub fn try_from_engine_data( engine_data: Box<dyn EngineData>, ) -> Result<Box<ArrowEngineData>, Error>
Utility constructor to get a Box<ArrowEngineData> out of a Box<dyn EngineData>
Sourcepub fn record_batch(&self) -> &RecordBatch
pub fn record_batch(&self) -> &RecordBatch
Get a reference to the RecordBatch this ArrowEngineData is wrapping