pub enum TransactionError {
VersionAlreadyExists(i64),
SerializeLogJson {
json_err: Error,
},
ObjectStore {
source: Error,
},
CommitConflict(CommitConflictError),
MaxCommitAttempts(i32),
DeltaTableAppendOnly,
UnsupportedTableFeatures(Vec<TableFeature>),
TableFeaturesRequired(TableFeature),
LogStoreError {
msg: String,
source: Box<dyn Error + Send + Sync + 'static>,
},
}Expand description
Error raised while commititng transaction
Variants
VersionAlreadyExists(i64)
Version already exists
SerializeLogJson
Error returned when reading the delta log object failed.
ObjectStore
Error returned when reading the delta log object failed.
CommitConflict(CommitConflictError)
Error returned when a commit conflict occurred
MaxCommitAttempts(i32)
Error returned when maximum number of commit trioals is exceeded
DeltaTableAppendOnly
The transaction includes Remove action with data change but Delta table is append-only
UnsupportedTableFeatures(Vec<TableFeature>)
Error returned when unsupported table features are required
TableFeaturesRequired(TableFeature)
Error returned when table features are required but not specified
LogStoreError
The transaction failed to commit due to an error in an implementation-specific layer. Currently used by DynamoDb-backed S3 log store when database operations fail.