pub enum TransactionError {
VersionAlreadyExists(i64),
SerializeLogJson {
json_err: Error,
},
ObjectStore {
source: Error,
},
CommitConflict(CommitConflictError),
MaxCommitAttempts(i32),
DeltaTableAppendOnly,
UnsupportedReaderFeatures(Vec<ReaderFeature>),
UnsupportedWriterFeatures(Vec<WriterFeature>),
WriterFeaturesRequired(WriterFeature),
ReaderFeaturesRequired(ReaderFeature),
LogStoreError {
msg: String,
source: Box<dyn Error + Send + Sync + 'static>,
},
}Expand description
Error raised while commititng transaction
Variants
VersionAlreadyExists(i64)
Version already exists
SerializeLogJson
Error returned when reading the delta log object failed.
ObjectStore
Error returned when reading the delta log object failed.
CommitConflict(CommitConflictError)
Error returned when a commit conflict occurred
MaxCommitAttempts(i32)
Error returned when maximum number of commit trioals is exceeded
DeltaTableAppendOnly
The transaction includes Remove action with data change but Delta table is append-only
UnsupportedReaderFeatures(Vec<ReaderFeature>)
Error returned when unsupported reader features are required
UnsupportedWriterFeatures(Vec<WriterFeature>)
Error returned when unsupported writer features are required
WriterFeaturesRequired(WriterFeature)
Error returned when writer features are required but not specified
ReaderFeaturesRequired(ReaderFeature)
Error returned when reader features are required but not specified
LogStoreError
The transaction failed to commit due to an error in an implementation-specific layer. Currently used by DynamoDb-backed S3 log store when database operations fail.